.. complexity documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

Contents
--------

.. toctree::
   :maxdepth: 1

   hope
   lang
   arch
   contributing
   authors
   history

Benchmarks
----------

All the benchmarks have been made available online as `IPython notebooks <http://refreweb.phys.ethz.ch/hope/benchmark.html>`_ (also on `GitHub <https://github.com/cosmo-ethz/hope/tree/master/benchmarks>`_). If you would like to run the benchmarks on your machine, you can download the notebooks in the nbviewer. 

**Note**: Make sure to execute the *native_cpp_gen* the first time in order to generate the native C++ code and some Python utility modules.

